@@ -13,20 +13,24 @@
 """
 __author__ = 'lth'
 
-from torch import nn
 import torch
+from torch import nn
+
+from ..utils import clamp
+
+
 class BCE(nn.Module):
-    def __init__(self,eps = 1e-5,reduction = "sum"):
+    def __init__(self, eps=1e-5, reduction="sum"):
         super(BCE, self).__init__()
 
-        assert reduction in ["sum","mean","none"]
+        assert reduction in ["sum", "mean", "none"]
         self.reduction = reduction
         self.eps = eps
 
-    def calculate(self,input_tensor,target):
-        input_tensor = self.clamp(input_tensor)
+    def calculate(self, input_tensor, target):
+        input_tensor = clamp(input_tensor, self.eps)
 
-        output = -target*torch.log(input_tensor)-(1.-target)*torch.log(1.-input_tensor)
+        output = -target * torch.log(input_tensor) - (1. - target) * torch.log(1. - input_tensor)
 
         if self.reduction is "sum":
             output = torch.sum(output)
@@ -38,11 +42,3 @@ class BCE(nn.Module):
             raise ValueError("reduction must be sum , mean , none")
 
         return output
-
-
-        return output
-
-
-    def clamp(self,input_tensor):
-        input_tensor = torch.clamp(input_tensor,self.eps,1-self.eps)
-        return input_tensor
\ No newline at end of file
