@@ -13,7 +13,7 @@
 """
 __author__ = 'lth'
 
-from .CTC import CTCFormal
+from lth_tools.torch_tools.Loss.CTC import CTCFormal
 from .GroupNorm import GroupNorm
 from .IdentityNode import IdentityNode
 from .SoftPool import SoftPooling1D,SoftPooling2D,SoftPooling3D
